pub enum HitCount {
Missed,
Tangent(LineHit),
Secant(LineHit, LineHit),
}Expand description
How a line meets a circle, hits in increasing parameter order.
Variants
Missed
The line misses the circle.
Tangent(LineHit)
The line touches the circle at exactly one point.
Secant(LineHit, LineHit)
The line crosses the circle at two points.